[why]
Starting from dp2 where dsc passthrough is introduced, it is required to 
identify
the dsc passthrough aux, apart from dsc decompression aux. Existing 
drm_dp_mst_port function
that returns dsc_aux alone is not sufficient.

[how]
1. Interface change in drm_dp_mst_dsc_aux_for_port, and dependency changes for 
each vendor.
2. Rename passthrough_aux with dsc_passthrough_aux to align with the name of 
dsc_aux.

Signed-off-by: Fangzhi Zuo <jerry....@amd.com>
Signed-off-by: Wayne Lin <wayne....@amd.com>
---
 .../amd/display/amdgpu_dm/amdgpu_dm_debugfs.c |  2 +-
 .../amd/display/amdgpu_dm/amdgpu_dm_helpers.c | 20 +++++------
 .../display/amdgpu_dm/amdgpu_dm_mst_types.c   | 28 +++++++--------
 drivers/gpu/drm/display/drm_dp_mst_topology.c | 34 +++++++++----------
 drivers/gpu/drm/i915/display/intel_dp.c       |  2 +-
 drivers/gpu/drm/i915/display/intel_dp_mst.c   |  3 +-
 include/drm/display/drm_dp_mst_helper.h       |  6 ++--
 7 files changed, 47 insertions(+), 48 deletions(-)

diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_debugfs.c 
b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_debugfs.c
index 6a97bb2d9160..6388cae166b1 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_debugfs.c
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_debugfs.c
@@ -1370,7 +1370,7 @@ static int dp_dsc_fec_support_show(struct seq_file *m, 
void *data)
                         * enable DSC on the sink device or on MST branch
                         * its connected to.
                         */
-                       if (aconnector->dsc_aux) {
+                       if (aconnector->mst_output_port->dsc_aux) {
                                is_fec_supported = true;
                                is_dsc_supported = true;
                        }
diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_helpers.c 
b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_helpers.c
index b0fea0856866..94ff77c8fd15 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_helpers.c
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_helpers.c
@@ -820,20 +820,20 @@ bool dm_helpers_dp_write_dsc_enable(
        uint8_t ret = 0;
 
        if (stream->signal == SIGNAL_TYPE_DISPLAY_PORT_MST) {
-               if (!aconnector->dsc_aux)
+               if (!aconnector->mst_output_port->dsc_aux)
                        return false;
 
                // apply w/a to synaptics
                if (needs_dsc_aux_workaround(aconnector->dc_link) &&
                    (aconnector->mst_downstream_port_present.byte & 0x7) != 0x3)
                        return write_dsc_enable_synaptics_non_virtual_dpcd_mst(
-                               aconnector->dsc_aux, stream, enable_dsc);
+                               aconnector->mst_output_port->dsc_aux, stream, 
enable_dsc);
 
                port = aconnector->mst_output_port;
 
                if (enable) {
-                       if (port->passthrough_aux) {
-                               ret = drm_dp_dpcd_write(port->passthrough_aux,
+                       if (port->dsc_passthrough_aux) {
+                               ret = 
drm_dp_dpcd_write(port->dsc_passthrough_aux,
                                                        DP_DSC_ENABLE,
                                                        &enable_passthrough, 1);
                                drm_dbg_dp(dev,
@@ -841,24 +841,24 @@ bool dm_helpers_dp_write_dsc_enable(
                                           ret);
                        }
 
-                       ret = drm_dp_dpcd_write(aconnector->dsc_aux,
+                       ret = 
drm_dp_dpcd_write(aconnector->mst_output_port->dsc_aux,
                                                DP_DSC_ENABLE, &enable_dsc, 1);
                        drm_dbg_dp(dev,
                                   "MST_DSC Sent DSC decoding enable to %s 
port, ret = %u\n",
-                                  (port->passthrough_aux) ? "remote RX" :
+                                  (port->dsc_passthrough_aux) ? "remote RX" :
                                   "virtual dpcd",
                                   ret);
                } else {
-                       ret = drm_dp_dpcd_write(aconnector->dsc_aux,
+                       ret = 
drm_dp_dpcd_write(aconnector->mst_output_port->dsc_aux,
                                                DP_DSC_ENABLE, &enable_dsc, 1);
                        drm_dbg_dp(dev,
                                   "MST_DSC Sent DSC decoding disable to %s 
port, ret = %u\n",
-                                  (port->passthrough_aux) ? "remote RX" :
+                                  (port->dsc_passthrough_aux) ? "remote RX" :
                                   "virtual dpcd",
                                   ret);
 
-                       if (port->passthrough_aux) {
-                               ret = drm_dp_dpcd_write(port->passthrough_aux,
+                       if (port->dsc_passthrough_aux) {
+                               ret = 
drm_dp_dpcd_write(port->dsc_passthrough_aux,
                                                        DP_DSC_ENABLE,
                                                        &enable_passthrough, 1);
                                drm_dbg_dp(dev,
diff --git a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_mst_types.c 
b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_mst_types.c
index 6e4359490613..a73b14fac07f 100644
--- a/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_mst_types.c
+++ b/drivers/gpu/drm/amd/display/amdgpu_dm/amdgpu_dm_mst_types.c
@@ -183,8 +183,8 @@ amdgpu_dm_mst_connector_early_unregister(struct 
drm_connector *connector)
                dc_sink_release(dc_sink);
                aconnector->dc_sink = NULL;
                aconnector->drm_edid = NULL;
-               aconnector->dsc_aux = NULL;
-               port->passthrough_aux = NULL;
+               aconnector->mst_output_port->dsc_aux = NULL;
+               aconnector->mst_output_port->dsc_passthrough_aux = NULL;
        }
 
        aconnector->mst_status = MST_STATUS_DEFAULT;
@@ -237,7 +237,7 @@ static bool validate_dsc_caps_on_connector(struct 
amdgpu_dm_connector *aconnecto
        u8 dsc_branch_dec_caps_raw[3] = { 0 };  // DSC branch decoder caps 0xA0 
~ 0xA2
        u8 *dsc_branch_dec_caps = NULL;
 
-       aconnector->dsc_aux = drm_dp_mst_dsc_aux_for_port(port);
+       drm_dp_mst_dsc_aux_for_port(port);
 
        /*
         * drm_dp_mst_dsc_aux_for_port() will return NULL for certain configs
@@ -250,19 +250,19 @@ static bool validate_dsc_caps_on_connector(struct 
amdgpu_dm_connector *aconnecto
         */
        if (!aconnector->dsc_aux && !port->parent->port_parent &&
            needs_dsc_aux_workaround(aconnector->dc_link))
-               aconnector->dsc_aux = &aconnector->mst_root->dm_dp_aux.aux;
+               aconnector->mst_output_port->dsc_aux = 
&aconnector->mst_root->dm_dp_aux.aux;
 
        /* synaptics cascaded MST hub case */
        if (is_synaptics_cascaded_panamera(aconnector->dc_link, port))
-               aconnector->dsc_aux = port->mgr->aux;
+               aconnector->mst_output_port->dsc_aux = port->mgr->aux;
 
-       if (!aconnector->dsc_aux)
+       if (!aconnector->mst_output_port->dsc_aux)
                return false;
 
-       if (drm_dp_dpcd_read(aconnector->dsc_aux, DP_DSC_SUPPORT, dsc_caps, 16) 
< 0)
+       if (drm_dp_dpcd_read(aconnector->mst_output_port->dsc_aux, 
DP_DSC_SUPPORT, dsc_caps, 16) < 0)
                return false;
 
-       if (drm_dp_dpcd_read(aconnector->dsc_aux,
+       if (drm_dp_dpcd_read(aconnector->mst_output_port->dsc_aux,
                        DP_DSC_BRANCH_OVERALL_THROUGHPUT_0, 
dsc_branch_dec_caps_raw, 3) == 3)
                dsc_branch_dec_caps = dsc_branch_dec_caps_raw;
 
@@ -279,10 +279,10 @@ static bool retrieve_downstream_port_device(struct 
amdgpu_dm_connector *aconnect
 {
        union dp_downstream_port_present ds_port_present;
 
-       if (!aconnector->dsc_aux)
+       if (!aconnector->mst_output_port->dsc_aux)
                return false;
 
-       if (drm_dp_dpcd_read(aconnector->dsc_aux, DP_DOWNSTREAMPORT_PRESENT, 
&ds_port_present, 1) < 0) {
+       if (drm_dp_dpcd_read(aconnector->mst_output_port->dsc_aux, 
DP_DOWNSTREAMPORT_PRESENT, &ds_port_present, 1) < 0) {
                DRM_INFO("Failed to read downstream_port_present 0x05 from DFP 
of branch device\n");
                return false;
        }
@@ -505,8 +505,8 @@ dm_dp_mst_detect(struct drm_connector *connector,
                dc_sink_release(aconnector->dc_sink);
                aconnector->dc_sink = NULL;
                aconnector->drm_edid = NULL;
-               aconnector->dsc_aux = NULL;
-               port->passthrough_aux = NULL;
+               aconnector->mst_output_port->dsc_aux = NULL;
+               aconnector->mst_output_port->dsc_passthrough_aux = NULL;
 
                amdgpu_dm_set_mst_status(&aconnector->mst_status,
                        MST_REMOTE_EDID | MST_ALLOCATE_NEW_PAYLOAD | 
MST_CLEAR_ALLOCATED_PAYLOAD,
@@ -1802,13 +1802,13 @@ enum dc_status dm_dp_mst_is_port_support_mode(
        }
 
        /*DSC necessary case*/
-       if (!aconnector->dsc_aux)
+       if (!aconnector->mst_output_port->dsc_aux)
                return DC_FAIL_BANDWIDTH_VALIDATE;
 
        if (is_dsc_common_config_possible(stream, &bw_range)) {
 
                /*capable of dsc passthough. dsc bitstream along the entire 
path*/
-               if (aconnector->mst_output_port->passthrough_aux) {
+               if (aconnector->mst_output_port->dsc_passthrough_aux) {
                        if (bw_range.min_kbps > end_to_end_bw_in_kbps) {
                                DRM_DEBUG_DRIVER("MST_DSC dsc passthrough and 
decode at endpoint"
                                                 "Max dsc compression bw can't 
fit into end-to-end bw\n");
diff --git a/drivers/gpu/drm/display/drm_dp_mst_topology.c 
b/drivers/gpu/drm/display/drm_dp_mst_topology.c
index a4551c17a07f..483b623961e7 100644
--- a/drivers/gpu/drm/display/drm_dp_mst_topology.c
+++ b/drivers/gpu/drm/display/drm_dp_mst_topology.c
@@ -2259,7 +2259,7 @@ void drm_dp_mst_connector_early_unregister(struct 
drm_connector *connector,
                    port->aux.name, connector->kdev->kobj.name);
        drm_dp_aux_unregister_devnode(&port->aux);
        port->dsc_aux = NULL;
-       port->passthrough_aux = NULL;
+       port->dsc_passthrough_aux = NULL;
 }
 EXPORT_SYMBOL(drm_dp_mst_connector_early_unregister);
 
@@ -5447,7 +5447,8 @@ int drm_dp_mst_add_affected_dsc_crtcs(struct 
drm_atomic_state *state, struct drm
                if (!crtc)
                        continue;
 
-               if (!drm_dp_mst_dsc_aux_for_port(pos->port))
+               drm_dp_mst_dsc_aux_for_port(pos->port);
+               if (!pos->port->dsc_aux)
                        continue;
 
                crtc_state = drm_atomic_get_crtc_state(mst_state->base.state, 
crtc);
@@ -6019,16 +6020,13 @@ EXPORT_SYMBOL(drm_dp_mst_aux_for_parent);
  * Depending on the situation, DSC may be enabled via the endpoint aux,
  * the immediately upstream aux, or the connector's physical aux.
  *
- * This is both the correct aux to read DSC_CAPABILITY and the
- * correct aux to write DSC_ENABLED.
- *
- * This operation can be expensive (up to four aux reads), so
- * the caller should cache the return.
- *
  * Returns:
- * NULL if DSC cannot be enabled on this port, otherwise the aux device
+ * port->dsc_aux - point for dsc decompression
+ *   null if dsc decompression point not found
+ * port->dsc_passthrough_aux - point for dsc passthrough
+ *   null no dsc passthrough support found
  */
-struct drm_dp_aux *drm_dp_mst_dsc_aux_for_port(struct drm_dp_mst_port *port)
+void drm_dp_mst_dsc_aux_for_port(struct drm_dp_mst_port *port)
 {
        struct drm_dp_mst_topology_mgr *mgr = port->mgr;
        struct drm_dp_mst_port *immediate_upstream_port = NULL;
@@ -6041,17 +6039,17 @@ struct drm_dp_aux *drm_dp_mst_dsc_aux_for_port(struct 
drm_dp_mst_port *port)
        u8 fec_cap;
 
        if (!port)
-               return NULL;
+               return;
 
        port->dsc_aux = NULL;
-       port->passthrough_aux = NULL;
+       port->dsc_passthrough_aux = NULL;
 
        /* Policy start */
        if (!drm_dp_mst_is_end_device(port->pdt, port->mcs)) {
                drm_err(mgr->dev,
                        "MST_DSC Can't determine dsc aux for port %p which is 
not connected to end device\n",
                        port);
-               return NULL;
+               return;
        }
 
        if (port->parent->port_parent)
@@ -6079,12 +6077,12 @@ struct drm_dp_aux *drm_dp_mst_dsc_aux_for_port(struct 
drm_dp_mst_port *port)
                goto out_dsc_fail;
        }
 
-       /* Consider passthrough as the first option for dsc_aux/passthrough_aux 
*/
+       /* Consider passthrough as the first option for 
dsc_aux/dsc_passthrough_aux */
        if (endpoint_dsc & DP_DSC_DECOMPRESSION_IS_SUPPORTED &&
                        upstream_dsc & DP_DSC_PASSTHROUGH_IS_SUPPORTED) {
                dsc_port = port;
                port->dsc_aux = &port->aux;
-               port->passthrough_aux = upstream_aux;
+               port->dsc_passthrough_aux = upstream_aux;
                drm_info(mgr->dev, "MST_DSC dsc passthrough to endpoint\n");
        }
 
@@ -6147,11 +6145,11 @@ struct drm_dp_aux *drm_dp_mst_dsc_aux_for_port(struct 
drm_dp_mst_port *port)
                goto out_dsc_fail;
        }
 
-       return port->dsc_aux;
+       return;
 
 out_dsc_fail:
        port->dsc_aux = NULL;
-       port->passthrough_aux = NULL;
-       return NULL;
+       port->dsc_passthrough_aux = NULL;
+       return;
 }
 EXPORT_SYMBOL(drm_dp_mst_dsc_aux_for_port);
diff --git a/drivers/gpu/drm/i915/display/intel_dp.c 
b/drivers/gpu/drm/i915/display/intel_dp.c
index fbb096be02ad..139586a75c70 100644
--- a/drivers/gpu/drm/i915/display/intel_dp.c
+++ b/drivers/gpu/drm/i915/display/intel_dp.c
@@ -3262,7 +3262,7 @@ intel_dp_sink_set_dsc_passthrough(const struct 
intel_connector *connector,
 {
        struct drm_i915_private *i915 = to_i915(connector->base.dev);
        struct drm_dp_aux *aux = connector->port ?
-                                connector->port->passthrough_aux : NULL;
+                                connector->port->dsc_passthrough_aux : NULL;
 
        if (!aux)
                return;
diff --git a/drivers/gpu/drm/i915/display/intel_dp_mst.c 
b/drivers/gpu/drm/i915/display/intel_dp_mst.c
index 7be8fb047b6c..e4e137b1df9f 100644
--- a/drivers/gpu/drm/i915/display/intel_dp_mst.c
+++ b/drivers/gpu/drm/i915/display/intel_dp_mst.c
@@ -1721,7 +1721,8 @@ static struct drm_connector 
*intel_dp_add_mst_connector(struct drm_dp_mst_topolo
 
        intel_dp_init_modeset_retry_work(intel_connector);
 
-       intel_connector->dp.dsc_decompression_aux = 
drm_dp_mst_dsc_aux_for_port(port);
+       drm_dp_mst_dsc_aux_for_port(port);
+       intel_connector->dp.dsc_decompression_aux = port->dsc_aux;
        intel_dp_mst_read_decompression_port_dsc_caps(intel_dp, 
intel_connector);
        intel_connector->dp.dsc_hblank_expansion_quirk =
                detect_dsc_hblank_expansion_quirk(intel_connector);
diff --git a/include/drm/display/drm_dp_mst_helper.h 
b/include/drm/display/drm_dp_mst_helper.h
index 672e8f6b5655..630ecf872e68 100644
--- a/include/drm/display/drm_dp_mst_helper.h
+++ b/include/drm/display/drm_dp_mst_helper.h
@@ -82,7 +82,7 @@ struct drm_dp_mst_branch;
  * by &drm_dp_mst_topology_mgr.base.lock.
  * @dsc_aux: aux to which DSC decompression request should be sent,
  * only set if DSC decompression is possible.
  * @passthrough_aux: parent aux to which DSC pass-through requests should be
be
  * sent, only set if DSC pass-through is possible.
  * @parent: branch device parent of this port
  * @connector: DRM connector this port is connected to. Protected by
@@ -138,7 +138,7 @@ struct drm_dp_mst_port {
        struct drm_dp_mst_branch *mstb;
        struct drm_dp_aux aux; /* i2c bus for this port? */
        struct drm_dp_aux *dsc_aux;
-       struct drm_dp_aux *passthrough_aux;
+       struct drm_dp_aux *dsc_passthrough_aux;
        struct drm_dp_mst_branch *parent;
 
        struct drm_connector *connector;
@@ -959,7 +959,7 @@ bool drm_dp_mst_port_is_logical(struct drm_dp_mst_port 
*port)
 }
 
 struct drm_dp_aux *drm_dp_mst_aux_for_parent(struct drm_dp_mst_port *port);
-struct drm_dp_aux *drm_dp_mst_dsc_aux_for_port(struct drm_dp_mst_port *port);
+void drm_dp_mst_dsc_aux_for_port(struct drm_dp_mst_port *port);
 
 static inline struct drm_dp_mst_topology_state *
 to_drm_dp_mst_topology_state(struct drm_private_state *state)
@@ -82,7 +82,7 @@ struct drm_dp_mst_branch;
  * @dsc_aux: aux to which DSC decompression request should be sent,
  * only set if DSC decompression is possible.
- * @passthrough_aux: parent aux to which DSC pass-through requests should be
+ * @dsc_passthrough_aux: parent aux to which DSC pass-through requests should 
be
  * sent, only set if DSC pass-through is possible.
-- 
2.43.0

Reply via email to